<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Εντοπίστηκε περιβάλλον live. Παρακαλώ επιλέξτε το διαμέρισμα root
που θέλετε να τροποποιήσετε (εμφανίζονται μόνο διαμερίσματα Linux)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Χρήση απλοποιημένης δομής μενού, χωρίς υπομενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Χρήση επίπεδων μενού (χωρίς υπομενού)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Εκκίνηση του</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Ρύθμιση στο &apos;0&apos; για άμεση εκκίνηση χωρίς να εμφανίζεται το μενού ή στο &apos;-1&apos; για επ &apos;αόριστον παραμονή στο μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Εμφάνιση μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Παράμετροι πυρήνα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Με αυτή την επιλογή, οτιδήποτε επιλέξετε για την εκκίνηση του grub, θα αποθηκευτεί ως νέα προεπιλογή στο μέλλον</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Αποθήκευση της τελευταίας επιλογής εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Φόντο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Εικόνα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Ενεργοποίηση θέματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Μηνύματα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Πολύ αναλυτικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Αναλυτικά (προεπιλεγμένη ρύθμιση)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Περιορισμένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Εμφάνιση αρχείου καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Still running</source>
        <translation>Ακόμα τρέχει</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>Η διαδικασία εφαρμογής εξακολουθεί να λειτουργεί. Είστε βέβαιοι ότι θέλετε να αποσυνδεθείτε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Set timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Timeout in seconds:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <location filename="../mainwindow.cpp" line="441"/>
        <location filename="../mainwindow.cpp" line="1076"/>
        <source>Timeout: %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <location filename="../mainwindow.cpp" line="443"/>
        <location filename="../mainwindow.cpp" line="1075"/>
        <location filename="../mainwindow.cpp" line="1091"/>
        <source>Boot Next: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Removal confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Select EFI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="524"/>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Set name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Something went wrong, could not add entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Εγκατάσταση bootsplash, παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Updating sources</source>
        <translation>Ενημέρωση πηγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Installing</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Could not install the bootsplash.</source>
        <translation>Δεν ήταν δυνατή η εγκατάσταση της bootsplash.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Boot Current: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Could not create a temporary folder</source>
        <translation>Δεν ήταν δυνατή η δημιουργία ενός προσωρινού φακέλου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Cannot continue</source>
        <translation>Δεν μπορεί να συνεχιστεί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Δεν είναι δυνατή η δημιουργία περιβάλλοντος chroot, δεν είναι δυνατή η αλλαγή των επιλογών εκκίνησης. Έξοδος...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Updating configuration, please wait</source>
        <translation>Ενημέρωση διαμόρφωσης, παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>Updating initramfs...</source>
        <translation>Ενημέρωση initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <location filename="../mainwindow.cpp" line="1203"/>
        <source>Updating grub...</source>
        <translation>Ενημέρωση του grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>Changes have been successfully applied.</source>
        <translation>Οι αλλαγές έχουν εφαρμοστεί με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>About %1</source>
        <translation>Περί του %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="881"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="883"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Πρόγραμμα επιλογής των συνηθισμένων προτιμήσεων της εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="886"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="914"/>
        <source>Running in a Virtual Machine</source>
        <translation>Εκτέλεση σε εικονική μηχανή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="915"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Το τρέχον σύστημα εκτελείται σε εικονική μηχανή,
Η bootsplash του Plymouth θα λειτουργήσει με περιορισμένο τρόπο, επίσης δεν θα μπορείτε να κάνετε προεπισκόπηση του θέματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Plymouth packages not installed</source>
        <translation>Τα πακέτα του Plymouth δεν έχουν εγκατασταθεί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="923"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Τα πακέτα του Plymouth δεν είναι εγκατεστημένα.
Θέλετε να προχωρήσετε και να τα εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Εικόνες (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Press any key to close</source>
        <translation>Πατήστε οποιοδήποτε πλήκτρο για να κλείσει</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1051"/>
        <source>Log not found</source>
        <translation>Δεν βρέθηκε αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1051"/>
        <source>Could not find log at </source>
        <translation>Δεν ήταν δυνατή η εύρεση του αρχείου αλλαγών σε </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>Edit UEFI Boot Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <location filename="../mainwindow.cpp" line="1117"/>
        <source>Set ac&amp;tive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1065"/>
        <source>&amp;Add entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>Boot &amp;next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1067"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Move &amp;down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>&amp;Remove entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Re&amp;set next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1071"/>
        <source>Change &amp;timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <source>Move &amp;up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <location filename="../mainwindow.cpp" line="1091"/>
        <source>not set, will boot using list order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>Set &amp;inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1167"/>
        <source>Needs reboot</source>
        <translation>Χρειάζεται επανεκκίνηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1168"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Το Plymouth μόλις εγκαταστάθηκε, ίσως χρειαστεί να επανεκκινήσετε για να εμφανίσετε προεπισκοπήσεις</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1224"/>
        <source>Click to select theme</source>
        <translation>Κάντε κλικ για να επιλέξετε θέμα</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Πρόγραμμα επιλογής των συνηθισμένων προτιμήσεων της εκκίνησης</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως root, αποσυνδεθείτε και συνδεθείτε ως κανονικός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>Select image to display in bootloader</source>
        <translation>Επιλέξτε εικόνα για την εμφάνιση στο bootloader</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1234"/>
        <source>Select GRUB theme</source>
        <translation>Επιλέξτε θέμα GRUB</translation>
    </message>
</context>
</TS>
